colour_hdri.generation — Colour - HDRI 0.1.0 documentation

# Source code for colour_hdri.generation

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .weighting_functions import (
        normal_distribution_function,
        hat_function,
        weighting_function_Debevec1997)
    from .radiance import image_stack_to_radiance_image

    __all__ = []
    __all__ += ['normal_distribution_function',
                'hat_function',
                'weighting_function_Debevec1997']
    __all__ += ['image_stack_to_radiance_image']